@@ -2,10 +2,10 @@ package Tk::Bitmap;
 require Tk;
 require Tk::Image;
 
-use vars qw($VERSION @ISA);
-$VERSION = '3.004'; # $Id: //depot/Tk8/Bitmap/Bitmap.pm#4$
+use vars qw($VERSION);
+$VERSION = '3.006'; # $Id: //depot/Tk8/Bitmap/Bitmap.pm#6$
 
-@ISA = qw(Tk::Image);
+use base  qw(Tk::Image);
 
 Construct Tk::Image 'Bitmap';
 
