@@ -8,11 +8,8 @@ package Tk::DialogBox;
 use strict;
 use Carp;
 
-require Tk::Toplevel;
-require Tk::Frame;
-
 use vars qw($VERSION);
-$VERSION = '3.020'; # $Id: //depot/Tk8/Tixish/DialogBox.pm#20$
+$VERSION = '3.027'; # $Id: //depot/Tk8/Tixish/DialogBox.pm#27$
 
 use base  qw(Tk::Toplevel);
 
@@ -42,14 +39,13 @@ sub Populate {
 
     # create a row of buttons in the bottom.
     my $bl;  # foreach my $var: perl > 5.003_08
-    foreach $bl (@$buttons) {
-	$b = $bot->Button(-text => $bl,
-			  -command => [ sub {
-			      $_[0]->{'selected_button'} = $_[1];
-			  }, $cw, $bl]);
-        if ($Tk::platform eq 'MSWin32') {
-            $b->configure(-width => 10, -pady => 0);
-        }
+    foreach $bl (@$buttons) 
+     {
+	my $b = $bot->Button(-text => $bl, -command => sub { $cw->{'selected_button'} = "$bl" } );
+        if ($Tk::platform eq 'MSWin32') 
+         {
+          $b->configure(-width => 10, -pady => 0);
+         }
 	if ($bl eq $default_button) {
             if ($Tk::platform eq 'MSWin32') {
                 $b->pack(-side => 'left', -expand => 1,  -padx => 1, -pady => 1);
@@ -59,27 +55,36 @@ sub Populate {
 	        $b->pack(-in => $db, -padx => '2', -pady => '2');
 	        $db->pack(-side => 'left', -expand => 1, -padx => 1, -pady => 1);
             }
-	    $cw->bind('<Return>' => [ 'Return', $cw, $b, $bl]);
+	    $cw->bind('<Return>' => [ $b, 'Invoke']);
 	    $cw->{'default_button'} = $b;
 	} else {
 	    $b->pack(-side => 'left', -expand => 1,  -padx => 1, -pady => 1);
 	}
-    }
+    }                
+    $cw->ConfigSpecs( -fg         => ['ADVERTISED','foreground','Foreground','black'],
+                      -foreground => ['ADVERTISED','foreground','Foreground','black'],
+                      -bg         => ['DESCENDANTS','background','Background',undef],
+                      -background => ['DESCENDANTS','background','Background',undef],
+                      -command    => ['CALLBACK', undef, undef, undef ], 
+                    );
     $cw->Delegates('Construct',$top);
 }
 
-sub Return {
-    $_[2]->flash;
-    $_[1]->{'selected_button'} = $_[3];
-}
-
-
 sub add {
     my ($cw, $wnam, @args) = @_;
     my $w = $cw->Subwidget('top')->$wnam(@args);
     $cw->Advertise("\L$wnam" => $w);
     return $w;
 }
+          
+sub Wait
+{
+ my $cw = shift;
+ $cw->waitVariable(\$cw->{'selected_button'});
+ $cw->grabRelease;
+ $cw->withdraw;
+ $cw->Callback(-command => $cw->{'selected_button'});
+}
 
 sub Show {
     my ($cw, $grab) = @_;
@@ -88,24 +93,21 @@ sub Show {
     my $old_focus = $cw->focusSave;
     my $old_grab = $cw->grabSave;
 
-    $cw->Subwidget('top')->pack;
-    $cw->Subwidget('bottom')->pack;
-
     $cw->Popup();
+
+    Tk::catch {
     if (defined $grab && length $grab && ($grab =~ /global/)) {
 	$cw->grabGlobal;
     } else {
 	$cw->grab;
     }
-    $cw->waitVisibility;
+    };
     if (defined $cw->{'default_button'}) {
 	$cw->{'default_button'}->focus;
     } else {
 	$cw->focus;
-    }
-    $cw->waitVariable(\$cw->{'selected_button'});
-    $cw->grabRelease;
-    $cw->withdraw;
+    }   
+    $cw->Wait;
     &$old_focus;
     &$old_grab;
     return $cw->{'selected_button'};
