@@ -1,7 +1,7 @@
 package Tk::ProgressBar;
 
 use vars qw($VERSION);
-$VERSION = '3.008'; # $Id: //depot/Tk8/Tk/ProgressBar.pm#8 $
+$VERSION = '3.002'; # $Id: //depot/Tk8/Tk/ProgressBar.pm#2$
 
 use Tk;
 use Tk::Canvas;
@@ -18,7 +18,6 @@ sub ClassInit {
     $class->SUPER::ClassInit($mw);
 
     $mw->bind($class,'<Configure>', ['_layoutRequest',1]);
-    $mw->bind($class,'<Destroy>', 'Destroyed');
 }
 
 
@@ -36,7 +35,6 @@ sub Populate {
 	-gap      => [PASSIVE => undef, undef, 1],
 	-colors   => [PASSIVE => undef, undef, undef],
 	-relief	  => [SELF => 'relief', 'Relief', 'sunken'],
-	-value    => [METHOD  => undef, undef, undef],
 	-variable => [METHOD  => undef, undef, undef],
 	-anchor   => [METHOD  => 'anchor', 'Anchor', 'w'],
 	-resolution
@@ -86,7 +84,7 @@ sub _arrange {
     my $from = $c->{Configure}{'-from'}; 
     my $to   = $c->{Configure}{'-to'};
     my $horz = $c->{Configure}{'-anchor'} =~ /[ew]/i ? 1 : 0;
-    my $dir  = $c->{Configure}{'-anchor'} =~ /[ne]/i ? -1 : 1;
+    my $dir  = $c->{Configure}{'-anchor'} =~ /[nw]/i ? -1 : 1;
 
     my($minv,$maxv) = $from < $to ? ($from,$to) : ($to,$from);
 
@@ -95,10 +93,10 @@ sub _arrange {
 	my $defw = 10 + $y*2 + $bw *2;
 	my $defl = ($maxv - $minv) + $x*2 + $bw*2;
 
-	$h = $c->pixels($c->{Configure}{'-length'}) || $defl;
-	$w = $c->pixels($c->{Configure}{'-width'})  || $defw;
+	$h = $c->{Configure}{'-length'} || $defw;
+	$w = $c->{Configure}{'-width'}  || $defl;
 
-	($w,$h) = ($h,$w) if $horz;
+	($w,$h) = ($h,$w) unless $horz;
 	$c->GeometryRequest($w,$h);
 	$c->parent->update;
 	$c->update;
@@ -294,29 +292,37 @@ sub value {
     $old;
 }
 
+##
+## A poor-man's watchvar until we have a proper watchvar
+##
+
+sub _afterit {
+    my $c = shift;
+    return unless defined($c->{Configure}{'-variable'});
+
+    if(${$c->{Configure}{'-variable'}} != $c->{Configure}{'-value'}) {
+	$c->{Configure}{'-value'} = ${$c->{Configure}{'-variable'}};
+	_layoutRequest($c,2);
+    }
+
+    $c->after(100, [ \&_afterit, $c]);
+}
+
 sub variable {
     my $c = shift;
     my $val = \$c->{Configure}{'-variable'};
     my $old = $$val;
+
     if(@_) {
 	my $value = shift;
-        if (ref $old)
-         {
-          $c->{Configure}{'-value'} = $$old;
-          untie $$old if tied($$old);
-         }
-        tie $$value,'Tk::Configure',$c,'-value';
-	$$val = $value;   
+	$c->{Configure}{'-value'} = $$old
+		if ref($old);
+	$$val = $value;
+	_afterit($c);
 	_layoutRequest($c,2);
     }
-    $old;
-}
 
-sub Destroyed
-{
- my $c = shift;
- my $var = delete $c->{Configure}{'-variable'};
- untie $$var if (defined($var) && ref($var))
+    $old;
 }
 
 1;
@@ -326,8 +332,6 @@ __END__
 
 Tk::ProgressBar - A graphical progress bar
 
-=for category Derived Widgets
-
 =head1 SYNOPSIS
 
     use Tk::ProgressBar;
