@@ -4,10 +4,10 @@ require Tk;
 use Exporter;
 
 
-use vars qw($VERSION @ISA @EXPORT_OK);
-$VERSION = '3.004'; # $Id: //depot/Tk8/Xlib/Xlib.pm#4$
+use vars qw($VERSION @EXPORT_OK);
+$VERSION = '3.006'; # $Id: //depot/Tk8/Xlib/Xlib.pm#6$
 
-@ISA = qw(DynaLoader Exporter);
+use base  qw(DynaLoader Exporter);
 @EXPORT_OK = qw(XDrawString XLoadFont XDrawRectangle);
 
 bootstrap Tk::Xlib $Tk::VERSION;
